@@ -13,7 +13,7 @@ def grpc_try_catch_wrapper(exception_message: str):
                 if isinstance(e, grpc.RpcError):
                     # noinspection PyUnresolvedReferences
                     raise FrogmlException(
-                        exception_message + f". Error is: {e.details()}."
+                        exception_message + f". Error is: {e}."
                     ) from e
 
                 raise e
