@@ -796,7 +796,7 @@ class FrogMLClient:
         run_tests: bool = True,
         validate_build_artifact: bool = True,
         validate_build_artifact_timeout: Optional[int] = None,
-        prebuilt_frogml_model: Optional[Model] = None,
+        prebuilt_frogml_model: Optional[BaseModel] = None,
         base_image: Optional[str] = None,
         build_name: str = "",
     ):
